@@ -1,4 +1,4 @@
-package Dist::Zilla::PluginBundle::Author::Plicease 2.55 {
+package Dist::Zilla::PluginBundle::Author::Plicease 2.56 {
 
   use 5.014;
   use Moose;
@@ -48,7 +48,8 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.55 {
     }
     else
     {
-      package Archive::Tar::Wrapper;
+      package
+        Archive::Tar::Wrapper;
       *new = sub { die "do not use ATW" };
       $INC{"Archive/Tar/Wrapper.pm"} = __FILE__;
     }
@@ -306,7 +307,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 2.55
+version 2.56
 
 =head1 SYNOPSIS
 
